/*******************************************************************************
 * Copyright (c) 2016 1C-Soft LLC.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Vladimir Piskarev (1C) - initial API and implementation
 *******************************************************************************/
package model;

import java.lang.reflect.Array;
import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.runtime.CoreException;

import model.impl.IHElementImpl;

/**
 * TODO JavaDoc
 */
public interface IHElementMirror
{
    default IHElement hElement()
    {
        return (IHElement)this;
    }

    default String getName()
    {
        return ((IHElementImpl)hElement()).hName();
    }

    default IHElement getParent()
    {
        return ((IHElementImpl)hElement()).hParent();
    }

    default <T> T getAncestor(Class<T> ancestorType)
    {
        IHElement parent = getParent();
        if (parent == null)
            return null;
        if (ancestorType.isInstance(parent))
            return ancestorType.cast(parent);
        return parent.hMirror().getAncestor(ancestorType);
    }

    default IHElement[] getChildren() throws CoreException
    {
        return ((IHElementImpl)hElement()).hChildren();
    }

    default <T> T[] getChildren(Class<T> childType) throws CoreException
    {
        IHElement[] children = getChildren();
        List<T> list = new ArrayList<T>(children.length);
        for (IHElement child : children)
        {
            if (childType.isInstance(child))
                list.add(childType.cast(child));
        }
        @SuppressWarnings("unchecked")
        T[] result = (T[])Array.newInstance(childType, list.size());
        return list.toArray(result);
    }
    
    default IResource getResource()
    {
        return ((IHElementImpl)hElement()).hResource();
    }
}
