/*******************************************************************************
 * Copyright (c) 2016 1C-Soft LLC.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Vladimir Piskarev (1C) - initial API and implementation
 *******************************************************************************/
package model.test;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IResourceDelta;

import junit.framework.TestCase;
import model.IHElement;
import model.IHElementChangeEvent;
import model.IHElementChangeListener;
import model.IHElementDelta;
import model.IHElementDeltaMirror;
import model.IHElementMirror;
import model.IHSourceElement;
import model.IHSourceElementMirror;
import model.IHSourceFile;
import model.IHSourceFileMirror;
import model.impl.HElementChangeEvent;

/**
 * TODO JavaDoc
 */
public class Test
    extends TestCase
{
    public void testFooElement() throws Exception
    {
        IFooElement element = new FooElement();
        String name = element.getName();
        assertNull(name);
        IFooElement parent = element.getParent();
        assertNull(parent);
        IFooElement[] children = element.getChildren();
        assertEquals(0, children.length);
        IResource resource = element.getResource();
        assertNull(resource);
        IHElementMirror hMirror = element.hMirror();
        assertSame(element, hMirror);
        IHElement hElement = element.hElement();
        assertSame(element, hElement);
    }

    public void testFooSourceElement() throws Exception
    {
        IFooSourceElement element = new FooSourceElement();
        String name = element.getName();
        assertNull(name);
        IFooElement parent = element.getParent();
        assertNull(parent);
        IFooElement[] children = element.getChildren();
        assertEquals(0, children.length);
        IResource resource = element.getResource();
        assertNull(resource);
        IFooSourceElement elementAt = element.getSourceElementAt(0);
        assertNull(elementAt);
        IHSourceElementMirror hMirror = element.hMirror();
        assertSame(element, hMirror);
        IHSourceElement hElement = element.hElement();
        assertSame(element, hElement);
    }

    public void testFooSourceFile() throws Exception
    {
        IFooSourceFile element = new FooSourceFile();
        String name = element.getName();
        assertNull(name);
        IFooElement parent = element.getParent();
        assertNull(parent);
        IFooElement[] children = element.getChildren();
        assertEquals(0, children.length);
        IResource resource = element.getResource();
        assertNull(resource);
        IFooSourceElement elementAt = element.getSourceElementAt(0);
        assertNull(elementAt);
        element.reconcile(true, null);
        IHSourceFileMirror hMirror = element.hMirror();
        assertSame(element, hMirror);
        IHSourceFile hElement = element.hElement();
        assertSame(element, hElement);
    }

    public void testFooElementDelta()
    {
        IFooElementDelta delta = new FooElementDelta();
        IFooElement element = delta.getElement();
        assertNull(element);
        int kind = delta.getKind();
        assertEquals(0, kind);
        long flags = delta.getFlags();
        assertEquals(0, flags);
        IFooElementDelta[] children = delta.getAffectedChildren();
        assertEquals(0, children.length);
        IHElementDeltaMirror hMirror = delta.hMirror();
        assertSame(delta, hMirror);
        IHElementDelta hDelta = delta.hDelta();
        assertSame(delta, hDelta);
        IHElementChangeListener listener = new IHElementChangeListener()
        {
            @Override
            public void elementChanged(IHElementChangeEvent event)
            {
                assertSame(delta, event.getDelta());
            }
        };
        listener.elementChanged(new HElementChangeEvent(
            IHElementChangeEvent.POST_CHANGE, delta));
    }

    public void testFooElementDelta2()
    {
        IFooElementDelta delta = new FooElementDelta();
        IResourceDelta[] resourceDeltas = delta.getResourceDeltas();
        assertNull(resourceDeltas);
    }

    public void testFooElementDelta3()
    {
        FooElementDelta delta = new FooElementDelta();
        try
        {
            delta.hAddResourceDelta(null);
            fail();
        }
        catch (IllegalArgumentException e)
        {
        }
    }
}
