/*******************************************************************************
 * Copyright (c) 2016 1C-Soft LLC.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Vladimir Piskarev (1C) - initial API and implementation
 *******************************************************************************/
package model.test2;

import java.util.Arrays;
import java.util.List;

import junit.framework.TestCase;
import model.IHElement;
import model.IHElementChangeEvent;
import model.IHElementChangeListener;
import model.IHElementDelta;
import model.IHElementDeltaMirror;
import model.IHElementMirror;
import model.IHSourceElement;
import model.IHSourceElementMirror;
import model.IHSourceFile;
import model.IHSourceFileMirror;
import model.impl.HElementChangeEvent;

/**
 * TODO JavaDoc
 */
public class Test
    extends TestCase
{
    public void testFooElement() throws Exception
    {
        IFooElement element = new FooElement();
        String name = element.getElementName();
        assertNull(name);
        IFooElement parent = element.getParent();
        assertNull(parent);
        List<IFooElement> children = element.getChildren();
        assertEquals(0, children.size());
        IHElementMirror hMirror = element.hMirror();
        assertNotSame(element, hMirror);
        IHElement hElement = hMirror.hElement();
        assertSame(element, hElement);
        String name2 = hMirror.getName();
        assertEquals(name, name2);
        IHElement parent2 = hMirror.getParent();
        assertEquals(parent, parent2);
        IHElement[] children2 = hMirror.getChildren();
        assertEquals(children, Arrays.asList(children2));
    }

    public void testFooSourceElement() throws Exception
    {
        IFooSourceElement element = new FooSourceElement();
        String name = element.getElementName();
        assertNull(name);
        IFooElement parent = element.getParent();
        assertNull(parent);
        List<IFooElement> children = element.getChildren();
        assertEquals(0, children.size());
        IFooSourceElement elementAt = element.getSourceElementAt(0);
        assertNull(elementAt);
        IHSourceElementMirror hMirror = element.hMirror();
        assertNotSame(element, hMirror);
        IHSourceElement hElement = hMirror.hElement();
        assertSame(element, hElement);
        String name2 = hMirror.getName();
        assertEquals(name, name2);
        IHElement parent2 = hMirror.getParent();
        assertEquals(parent, parent2);
        IHElement[] children2 = hMirror.getChildren();
        assertEquals(children, Arrays.asList(children2));
        IHSourceElement elementAt2 = hMirror.getSourceElementAt(0);
        assertEquals(elementAt, elementAt2);
    }

    public void testFooSourceFile() throws Exception
    {
        IFooSourceFile element = new FooSourceFile();
        String name = element.getElementName();
        assertNull(name);
        IFooElement parent = element.getParent();
        assertNull(parent);
        List<IFooElement> children = element.getChildren();
        assertEquals(0, children.size());
        IFooSourceElement elementAt = element.getSourceElementAt(0);
        assertNull(elementAt);
        element.reconcile(IFooSourceFile.FORCE_PROBLEM_DETECTION, null);
        IHSourceFileMirror hMirror = element.hMirror();
        assertNotSame(element, hMirror);
        IHSourceFile hElement = hMirror.hElement();
        assertSame(element, hElement);
        String name2 = hMirror.getName();
        assertEquals(name, name2);
        IHElement parent2 = hMirror.getParent();
        assertEquals(parent, parent2);
        IHElement[] children2 = hMirror.getChildren();
        assertEquals(children, Arrays.asList(children2));
        IHSourceElement elementAt2 = hMirror.getSourceElementAt(0);
        assertEquals(elementAt, elementAt2);
        hMirror.reconcile(true, null);
    }

    public void testFooElementDelta()
    {
        IFooElementDelta delta = new FooElementDelta();
        IFooElement element = delta.getElement();
        assertNull(element);
        int kind = delta.getDeltaKind();
        assertEquals(0, kind);
        long flags = delta.getChangeFlags();
        assertEquals(0, flags);
        List<IFooElementDelta> children = delta.getAffectedChildren();
        assertEquals(0, children.size());
        IHElementDeltaMirror hMirror = delta.hMirror();
        assertNotSame(delta, hMirror);
        IHElementDelta hDelta = hMirror.hDelta();
        assertSame(delta, hDelta);
        IHElement element2 = hMirror.getElement();
        assertEquals(element, element2);
        int kind2 = hMirror.getKind();
        assertEquals(kind, kind2);
        long flags2 = hMirror.getFlags();
        assertEquals(flags, flags2);
        IHElementDelta[] children2 = hMirror.getAffectedChildren();
        assertEquals(children, Arrays.asList(children2));
        IHElementChangeListener listener = new IHElementChangeListener()
        {
            @Override
            public void elementChanged(IHElementChangeEvent event)
            {
                assertSame(delta, event.getDelta());
            }
        };
        listener.elementChanged(new HElementChangeEvent(
            IHElementChangeEvent.POST_CHANGE, delta));
    }
}
